@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# (c) Copyright 2003-2009 Hewlett-Packard Development Company, L.P.
+# (c) Copyright 2010 Hewlett-Packard Development Company, L.P.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -65,6 +65,10 @@ STATUS_CREATING_COVER_PAGE = 7
 STATUS_ERROR = 8
 STATUS_BUSY = 9
 STATUS_CLEANUP = 10
+STATUS_ERROR_IN_CONNECTING = 11
+STATUS_ERROR_IN_TRANSMITTING = 12
+STATUS_ERROR_PROBLEM_IN_FAXLINE = 13
+STATUS_JOB_CANCEL = 14 
 
 # Event queue values (UI ==> Send thread)
 EVENT_FAX_SEND_CANCELED = 1
@@ -132,7 +136,6 @@ RESOLUTION_300DPI = 3
 
 FILE_HEADER_SIZE = 28
 PAGE_HEADER_SIZE = 24
-
 # **************************************************************************** #
 
 ##skip_dn = ["uid=foo,ou=People,dc=example,dc=com",
@@ -203,17 +206,18 @@ class FaxAddressBook(object): # Pickle based address book
         self.load()
 
     def load(self):
-        self._fab = os.path.join(prop.user_dir, "fab.pickle")
-        #old_fab = os.path.join(prop.user_dir, "fab.db")
+        self._fab = "/dev/null"
+        if prop.user_dir != None:
+            self._fab = os.path.join(prop.user_dir, "fab.pickle")
+            #old_fab = os.path.join(prop.user_dir, "fab.db")
 
-        # Load the existing pickle if present
-        if os.path.exists(self._fab):
-            pickle_file = open(self._fab, "r")
-            self._data = cPickle.load(pickle_file)
-            pickle_file.close()
-
-        else:
-            self.save() # save the empty file to create the file
+            # Load the existing pickle if present
+            if os.path.exists(self._fab):
+               pickle_file = open(self._fab, "r")
+               self._data = cPickle.load(pickle_file)
+               pickle_file.close()
+            else:
+               self.save() # save the empty file to create the file
 
 
     def set(self, name, title, firstname, lastname, fax, groups, notes):
@@ -520,12 +524,26 @@ def getFaxDevice(device_uri=None, printer_name=None,
         from soapfax import SOAPFaxDevice
         return SOAPFaxDevice(device_uri, printer_name, callback, fax_type, disable_dbus)
 
+    elif fax_type == FAX_TYPE_LEDMSOAP:
+        from ledmsoapfax import LEDMSOAPFaxDevice
+        return LEDMSOAPFaxDevice(device_uri, printer_name, callback, fax_type, disable_dbus)
+
+    elif fax_type == FAX_TYPE_MARVELL:
+        from marvellfax import MarvellFaxDevice
+        return MarvellFaxDevice(device_uri, printer_name, callback, fax_type, disable_dbus)
+
+    elif fax_type == FAX_TYPE_LEDM:
+        from ledmfax import LEDMFaxDevice
+        return LEDMFaxDevice(device_uri, printer_name, callback, fax_type, disable_dbus)
+
     else:
         raise Error(ERROR_DEVICE_DOES_NOT_SUPPORT_OPERATION)
 
 # **************************************************************************** #
 
 
+
+
 # TODO: Define these in only 1 place!
 STATE_DONE = 0
 STATE_ABORTED = 10
@@ -830,6 +848,10 @@ class FaxSendThread(threading.Thread):
         for a in self.phone_num_list:
             yield a
 
+    def next_file_gen(self):
+        for a in self.recipient_file_list:
+            yield a
+
 
     def render_file(self, path, title, mime_type, force_single_page=False):
         all_pages = True
@@ -908,6 +930,7 @@ class FaxSendThread(threading.Thread):
     def render_cover_page(self, a):
         log.debug("Creating cover page...")
 
+        user_conf.read()
         pdf = self.cover_func(page_size=coverpages.PAGE_SIZE_LETTER,
                               total_pages=self.job_total_pages,
 
